@@ -21,6 +21,7 @@
 #include "snd_dice.h"
 #include "snd_efw.h"
 #include "snd_dg00x.h"
+#include "snd_motu.h"
 
 void hinawa_fw_unit_ioctl(HinawaFwUnit *self, int req, void *args, int *err);
 void hinawa_fw_resp_handle_request(HinawaFwResp *self,
@@ -32,10 +33,21 @@ void hinawa_snd_unit_write(HinawaSndUnit *self,
 			   const void *buf, unsigned int length,
 			   GError **exception);
 
+#if HAVE_SND_DICE
 void hinawa_snd_dice_handle_notification(HinawaSndDice *self,
 					 const void *buf, unsigned int len);
+#endif
+#if HAVE_SND_EFW
 void hinawa_snd_efw_handle_response(HinawaSndEfw *self,
 				    const void *buf, unsigned int len);
+#endif
+#if HAVE_SND_DG00X
 void hinawa_snd_dg00x_handle_msg(HinawaSndDg00x *self, const void *buf,
 				 unsigned int len);
 #endif
+#if HAVE_SND_MOTU
+void hinawa_snd_motu_handle_notification(HinawaSndMotu *self,
+					 const void *buf, unsigned int len);
+#endif
+
+#endif
